#!/bin/bash
#
# ilink TeamCall CA Avaya
# linux-installer.sh
#
# Copyright (c) 1997-2003, 2006, 2013, 2015 by ilink Kommunikationssysteme GmbH.  All Rights Reserved.
#
# This script will configure and call the Java based command line installer for CA Avaya.
#
# Requirements:
# - The calling user must have root permissions.
# - java needs to be on the search path.
#


PATH=$PATH:/usr/bin:/usr/sbin:/sbin

OS_IDENTIFIER=$( uname -a | sed -e 's/ .*//' )
if [ "x$OS_IDENTIFIER" = "xLinux" ]; then
	echo "Running on Linux"
elif [ "x$OS_IDENTIFIER" = "xDarwin" ]; then
	echo "Running on OS X"
else
	echo ""
	echo "Running on unsupported operating system ($OS_IDENTIFIER)"
	echo "Installer canceled"
	echo ""
	exit 1
fi


# Check directory
if [ ! -f "linux-installer.sh" ]; then
	echo ""
	echo "You are not in the correct directory"
	echo "Please change to installer directory (ca_avaya_definity_install_x.x.x.x)"
	echo "Installer canceled"
	echo ""
	exit 1
fi


# Check for root permissions
perm=`id -u`
if [ "$perm" != "0" ]; then
	echo ""
	echo "You must be root to start the installer"
	echo "Installer canceled"
	echo ""
	exit 1
fi


# Set CA variables
ASAI_HOSTNAME="localhost"
ASAI_LINK="1"
ASAI_PORT="5678"
INSTALLCONFIG="install.config"                   # name of install config file
INSTALLERFILE="ca_avaya_definity_install.jar"    # name of java install pkg
INSTALLLOGFILE="CAAvaya-install.log"             # name of install log file
INSTALLPATH="/usr/local/ilink/CAAvayaDefinity"
LANG="deu"
OP_PREFIX=""
SERVER_PORT="25535"
SERVICE_SUFFIX="1"


# Set install script variables
DEBUGOPTIONS="-DTRACE=true -DSTACKTRACE=true"    # IzPack installer debug options
JAVA_BIN=java                                    # java needs to be on the search path


# Get and confirm all parameters
checkParameter="0"
while [ "$checkParameter" != "OK" ]
do
	clear
	echo "Command line installer"

echo -e "Avaya Definity Hostname [$ASAI_HOSTNAME]:\c "
	read ASAI_HOSTNAME_TMP

	if [ "$ASAI_HOSTNAME_TMP" != "" ];then
		ASAI_HOSTNAME="$ASAI_HOSTNAME_TMP"
	fi

	echo -e "Avaya Definity ASAI Port [$ASAI_PORT]:\c "
	read ASAI_PORT_TMP

	if [ "$ASAI_PORT_TMP" != "" ];then
		ASAI_PORT="$ASAI_PORT_TMP"
	fi

	echo -e "ASAI Link [$ASAI_LINK]:\c "
	read ASAI_LINK_TMP

	if [ "$ASAI_LINK_TMP" != "" ];then
		ASAI_LINK="$ASAI_LINK_TMP"
	fi

	echo -e "Server Port [$SERVER_PORT]:\c "
	read SERVER_PORT_TMP

	if [ "$SERVER_PORT_TMP" != "" ];then
		SERVER_PORT="$SERVER_PORT_TMP"
	fi

	echo -e "Outside Line Prefix [$OP_PREFIX]:\c "
	read OP_PREFIX_TMP

	if [ "$OP_PREFIX_TMP" != "" ];then
		OP_PREFIX="$OP_PREFIX_TMP"
	fi

	echo -e "Service Suffix [$SERVICE_SUFFIX]:\c "
	read SERVICE_SUFFIX_TMP

	if [ "$SERVICE_SUFFIX_TMP" != "" ];then
		SERVICE_SUFFIX="$SERVICE_SUFFIX_TMP"
	fi

	echo -e "Installation Path [$INSTALLPATH]:\c "
	read INSTALLPATH_TMP

	if [ "$INSTALLPATH_TMP" != "" ];then
		INSTALLPATH="$INSTALLPATH_TMP"
	fi

	echo "--------------------------------------------"
	echo "          Check our settings!"
	echo ""
	echo " Avaya Definity Hostname:  $ASAI_HOSTNAME"
	echo " Avaya Definity ASAI Port: $ASAI_PORT"
	echo " ASAI Link:                $ASAI_LINK"
	echo " Server Port:              $SERVER_PORT"
	echo " Outside Line Prefix:      $OP_PREFIX"
	echo " Service Suffix:           $SERVICE_SUFFIX"
	echo " Installation Path:        $INSTALLPATH"
	echo ""
	echo "---------------------------------------------"

	checker="0"
	echo -e "Are these settings correct? Then type OK: \c"
	read checker

	if [ "$checker" == "OK" ];then
		checkParameter="OK"
	fi
done


# Create a config file for installation
cat > $INSTALLCONFIG << EOF
<AutomatedInstallation langpack="$LANG">
	<HelloPanel/>
	<UserInputPanel>
		<userInput>
			<entry key="ASAI_LINK" value="$ASAI_LINK"/>
			<entry key="SERVER_PORT" value="$ASAI_PORT"/>
			<entry key="ASAI_PORT" value="$ASAI_PORT"/>
			<entry key="ASAI_HOSTNAME" value="$ASAI_HOSTNAME"/>
			<entry key="SERVICE_SUFFIX" value="$SERVICE_SUFFIX"/>
		</userInput>
	</UserInputPanel>
	<TargetPanel>
		<installpath>$INSTALLPATH</installpath>
	</TargetPanel>
	<PacksPanel>
		<pack name="CAAvaya" index="0" selected="true"/>
	</PacksPanel>
	<InstallPanel/>
	<FinishPanel/>
</AutomatedInstallation>

EOF


# Start the IzPack installer
$JAVA_BIN $DEBUGOPTIONS -jar $INSTALLERFILE $INSTALLCONFIG | tee $INSTALLLOGFILE | egrep '\(./.\)'


# Remove superfluous lines from logfile
mv $INSTALLLOGFILE logfile_tmp
cat logfile_tmp | grep -v "current OS" > $INSTALLLOGFILE
rm logfile_tmp


# Remove created install.config file
rm $INSTALLCONFIG

